@@ -8,6 +8,7 @@ sensitivity_bootstrap <- function(ma_obj, boot_iter = 1000, boot_conf_level = .9
 
      class_ma <- class(ma_obj)
 
+     if(any(class_ma == "ma_generic")) es_type <- "es"
      if(any(class_ma == "ma_r_as_r" | class_ma == "ma_d_as_r")) es_type <- "r"
      if(any(class_ma == "ma_d_as_d" | class_ma == "ma_r_as_d")) es_type <- "d"
      if(is.null(es_type)) stop("ma_obj must represent a meta-analysis of correlations or d values", call. = FALSE)
@@ -25,6 +26,7 @@ sensitivity_bootstrap <- function(ma_obj, boot_iter = 1000, boot_conf_level = .9
           record_call <- TRUE
      }
 
+     ma_obj_i <- ma_obj
      ma_list <- lapply(ma_list, function(ma_obj_i){
           if(any(class(ma_obj_i) == "ma_ic")){
                ma_arg_list <- ma_obj_i$individual_correction$inputs
@@ -33,6 +35,14 @@ sensitivity_bootstrap <- function(ma_obj, boot_iter = 1000, boot_conf_level = .9
           }
 
           k_analyses <- nrow(ma_obj_i$barebones$meta_table)
+          if(es_type == "es"){
+               sample_id <- lapply(ma_obj_i$barebones$escalc_list, function(x) x$sample_id)
+               yi <-   lapply(ma_obj_i$barebones$escalc_list, function(x) x$yi)
+               n <-     lapply(ma_obj_i$barebones$escalc_list, function(x) x$n)
+               vi_xy <- lapply(ma_obj_i$barebones$escalc_list, function(x) x$vi)
+               wt_xy <- lapply(ma_obj_i$barebones$escalc_list, function(x) x$weight)
+          }
+
           if(es_type == "r"){
                sample_id <- lapply(ma_obj_i$barebones$escalc_list, function(x) x$sample_id)
                rxy <-   lapply(ma_obj_i$barebones$escalc_list, function(x) x$rxy)
@@ -105,6 +115,11 @@ sensitivity_bootstrap <- function(ma_obj, boot_iter = 1000, boot_conf_level = .9
           for(i in 1:k_analyses){
                analysis_id <- paste0("Analysis ID = ", i)
 
+               if(es_type == "es"){
+                    es_data <- data.frame(sample_id = sample_id[[i]],
+                                          yi = yi[[i]],
+                                          n = n[[i]])
+               }
                if(es_type == "r"){
                     es_data <- data.frame(sample_id = sample_id[[i]],
                                           rxy = rxy[[i]],
@@ -158,6 +173,12 @@ sensitivity_bootstrap <- function(ma_obj, boot_iter = 1000, boot_conf_level = .9
                     }
                }else{
                     if(any(class_ma == "ma_bb"))
+                         if(es_type == "es"){
+                              es_data$vi <- vi_xy[[i]]
+                              out_list$barebones[[analysis_id]] <- .ma_bootstrap(data = es_data, ma_fun_boot = .ma_generic_boot, boot_iter = boot_iter,
+                                                                                 boot_conf_level = boot_conf_level, boot_ci_type = boot_ci_type, ma_arg_list = ma_arg_list)
+                         }
+
                          if(es_type == "r")
                               out_list$barebones[[analysis_id]] <- .ma_bootstrap(data = es_data, ma_fun_boot = .ma_r_bb_boot, boot_iter = boot_iter,
                                                                                  boot_conf_level = boot_conf_level, boot_ci_type = boot_ci_type, ma_arg_list = ma_arg_list)
