@@ -4,6 +4,7 @@ sensitivity_leave1out <- function(ma_obj, ...){
 
      class_ma <- class(ma_obj)
 
+     if(any(class_ma == "ma_generic")) es_type <- "es"
      if(any(class_ma == "ma_r_as_r" | class_ma == "ma_r_as_d")) es_type <- "r"
      if(any(class_ma == "ma_d_as_d" | class_ma == "ma_d_as_r")) es_type <- "d"
 
@@ -34,6 +35,14 @@ sensitivity_leave1out <- function(ma_obj, ...){
           }
 
           k_analyses <- nrow(ma_obj_i$barebones$meta_table)
+          if(es_type == "es"){
+               sample_id <- lapply(ma_obj_i$barebones$escalc_list, function(x) x$sample_id)
+               yi <-   lapply(ma_obj_i$barebones$escalc_list, function(x) x$yi)
+               n <-     lapply(ma_obj_i$barebones$escalc_list, function(x) x$n)
+               vi_xy <- lapply(ma_obj_i$barebones$escalc_list, function(x) x$vi)
+               wt_xy <- lapply(ma_obj_i$barebones$escalc_list, function(x) x$weight)
+          }
+
           if(es_type == "r"){
                sample_id <- lapply(ma_obj_i$barebones$escalc_list, function(x) x$sample_id)
                rxy <-   lapply(ma_obj_i$barebones$escalc_list, function(x) x$rxy)
@@ -118,6 +127,11 @@ sensitivity_leave1out <- function(ma_obj, ...){
                conf_method <- ma_obj$barebones$inputs$conf_method
                cred_method <- ma_obj$barebones$inputs$cred_method
 
+               if(es_type == "es"){
+                    es_data <- data.frame(sample_id = sample_id[[i]],
+                                          yi = yi[[i]],
+                                          n = n[[i]])
+               }
                if(es_type == "r"){
                     es_data <- data.frame(sample_id = sample_id[[i]],
                                           rxy = rxy[[i]],
@@ -247,6 +261,12 @@ sensitivity_leave1out <- function(ma_obj, ...){
 
                          bb_mat <- ma_obj$barebones$meta_table[i,]
 
+                         if(es_type == "es"){
+                              es_data$vi <- vi_xy[[i]]
+                              es_data$weight <- wt_xy[[i]]
+                              bb_table <- .ma_leave1out(data = es_data, ma_fun_boot = .ma_generic_boot, ma_arg_list = ma_arg_list)
+                         }
+
                          if(es_type == "r"){
                               es_data$vi <- vi_xy[[i]]
                               es_data$weight <- wt_xy[[i]]
